#!/bin/bash
# Installation script for AnomalyDetection R-scripts

# only root can run script
if [ $EUID -ne 0 ]; then
	echo 'Run this script as root. Exiting.' 1>&2
	exit 1
fi

# checking if Linux OS
if [ "`uname -s`" != 'Linux' ]; then
	echo "This script is only for Linux systems" 1>&2
	exit 1
fi

timestamp=`date +%Y%m%d%H%M%S`
log="install_$timestamp.log"
rconf="R_conf_$timestamp.r"

echo "On errors please check log file: $log"

# installing R environment
if [ "$1" != 'no-R' ]; then 
	echo "Installing R environment..."

	if [ `head -1 /etc/issue | grep -c 'Debian'` == 1 \
          -o `head -1 /etc/issue | grep -c 'Mint'` == 1   \
          -o `head -1 /etc/issue | grep -c 'Ubuntu'` == 1 ]; then
		echo "    Updating package list."
		aptitude update 1>>$log 2>&1
		aptitude -y install wget r-base-core r-base-dev 1>>$log

	elif [ `head -1 /etc/fedora-release | grep -c 'Fedora'` == 1 \
             -o `head -1 /etc/redhat-release | grep -c 'Red Hat'` == 1 \
             -o `head -1 /etc/centos-release | grep -c 'CentOS'` == 1 \
             -o `head -1 /etc/oracle-release | grep -c 'Oracle'` == 1 ]; then
		yum -y install wget R-core R-devel 1>>$log

	else
		echo "This script is only for Debian, Mint, Ubuntu and Fedora distros.
Please install R-core and R-dev packages manually and run:
$0 no-R" 1>&2
		exit 1
	fi
	
	if [ $? -ne 0 ];then
		echo "Something went wrong. Please check install_$timestamp.log for errors. 
		For RedHat/Fedora/CentOS/OracleLinux consider adding EPEL repository. Exiting."
		exit 1
	fi
	
	echo "    Done."
else
	echo "Ommiting R environment installation - hope you've done it before."
fi

# creating dirs for PG & Evaluator
PG_DIR="/usr/local/src/profilegenerator"

if [ -d $PG_DIR ]; then
	echo "ProfileGenerator & Evaluator are currently installed.

	For update type:
	$PG_DIR/update_pg.sh
	Exiting." 1>&2
	exit 1
fi

echo "Installing ProfileGenerator & Evaluator."

echo "Creating directory..."
mkdir $PG_DIR
echo "    $PG_DIR created."

echo "Copying scripts..."
cp *.r $PG_DIR/
cp version $PG_DIR/
cp update_pg.sh $PG_DIR/
cp remove_pg.sh $PG_DIR/

chmod +rx $PG_DIR/*.r
chmod +rx $PG_DIR/*.sh

echo "Creating links..."
ln -s $PG_DIR/ad_profilegenerator.r /bin/profilegenerator
echo "    /bin/profilegenerator"
ln -s $PG_DIR/ad_evaluator.r /bin/evaluator
echo "    /bin/evaluator"

echo "Configuring R environment."

# installing required packages from cran repo
echo "options(\"repos\" = c(CRAN = \"http://cran.r-project.org/\"))
install.packages('getopt')
install.packages('quadprog')
install.packages('zoo')
install.packages('tseries')" > $rconf

R CMD BATCH $rconf R_$log
rm -f $rconf

echo "

==========[ R packages installation log ]==========" >> $log
cat R_$log >> $log
rm -f R_$log

if [ `grep -c "DONE" $log` -ne 4 ]; then 
  echo 'R configuration error occured...' 1>&2
  exit 1
fi

echo   "To update ProfileGenerator & Evaluator type:
    $PG_DIR/update_pg.sh

To remove ProfileGenerator & Evaluator type:
    $PG_DIR/remove_pg.sh"
echo "Done."


